@@ -86,6 +86,15 @@ class IPluginRegistry(metaclass=ABCMeta):
         """
         pass
 
+    @abstractmethod
+    def is_plugin_load_success(self) -> bool:
+        """
+        Whether plugin loading suceeded. load_plugin_with_hooks_impl method
+        finished successfully
+        :return: True if plugin load was successful
+        """
+        pass
+
     @abstractmethod
     def load_plugin_with_hooks_impl(
         self, module_or_class_with_hook_impls: object, name: str
