@@ -30,8 +30,8 @@ class TerminationMessageWriterPlugin:
     @hookimpl
     def vdk_exit(self, context: CoreContext, exit_code: int):
         self.write_termination_message(
-            errors.get_blamee_overall(),  # TODO: get this from context
-            errors.get_blamee_overall_user_error(),  # TODO: get this from context
+            errors.get_blamee_overall(),
+            errors.get_blamee_overall_user_error(),
             context.configuration,
         )
 
